@@ -22,22 +22,20 @@
 #include <config.h>
 #include "ephy-embed-shell.h"
 
-#ifndef HAVE_WEBKIT2
-#include "ephy-adblock-manager.h"
-#endif
+#include "ephy-about-handler.h"
 #include "ephy-debug.h"
 #include "ephy-download.h"
+#include "ephy-embed-prefs.h"
 #include "ephy-embed-private.h"
-#include "ephy-embed-single.h"
 #include "ephy-embed-type-builtins.h"
 #include "ephy-encodings.h"
 #include "ephy-file-helpers.h"
 #include "ephy-history-service.h"
 #include "ephy-profile-utils.h"
+#include "ephy-request-about.h"
+#include "ephy-settings.h"
 #include "ephy-snapshot-service.h"
-#ifdef HAVE_WEBKIT2
 #include "ephy-web-extension.h"
-#endif
 
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
@@ -45,6 +43,7 @@
 
 #define PAGE_SETUP_FILENAME "page-setup-gtk.ini"
 #define PRINT_SETTINGS_FILENAME "print-settings.ini"
+#define NSPLUGINWRAPPER_SETUP "/usr/bin/mozilla-plugin-config"
 
 #define EPHY_EMBED_SHELL_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_EMBED_SHELL, EphyEmbedShellPrivate))
 
@@ -52,21 +51,14 @@ struct _EphyEmbedShellPrivate
 {
   EphyHistoryService *global_history_service;
   GList *downloads;
-  EphyEmbedSingle *embed_single;
   EphyEncodings *encodings;
-#ifndef HAVE_WEBKIT2
-  EphyAdBlockManager *adblock_manager;
-#endif
   GtkPageSetup *page_setup;
   GtkPrintSettings *print_settings;
   EphyEmbedShellMode mode;
   EphyFrecentStore *frecent_store;
-  guint single_initialised : 1;
-#ifdef HAVE_WEBKIT2
   GDBusProxy *web_extension;
   guint web_extension_watch_name_id;
   guint web_extension_form_auth_save_signal_id;
-#endif
 };
 
 enum
@@ -106,41 +98,16 @@ ephy_embed_shell_dispose (GObject *object)
   g_clear_object (&priv->print_settings);
   g_clear_object (&priv->frecent_store);
   g_clear_object (&priv->global_history_service);
-  g_clear_object (&priv->embed_single);
-#ifdef HAVE_WEBKIT2
-  if (priv->web_extension_watch_name_id > 0) {
-    g_bus_unwatch_name (priv->web_extension_watch_name_id);
-    priv->web_extension_watch_name_id = 0;
+
+  if (priv->downloads != NULL) {
+    LOG ("Destroying downloads list");
+    g_list_free_full (priv->downloads, (GDestroyNotify)g_object_unref);
+    priv->downloads = NULL;
   }
-  if (priv->web_extension_form_auth_save_signal_id > 0) {
-    g_dbus_connection_signal_unsubscribe (g_dbus_proxy_get_connection (priv->web_extension),
-                                          priv->web_extension_form_auth_save_signal_id);
-    priv->web_extension_form_auth_save_signal_id = 0;
-  }
-  g_clear_object (&priv->web_extension);
-#else
-  g_clear_object (&priv->adblock_manager);
-#endif
 
   G_OBJECT_CLASS (ephy_embed_shell_parent_class)->dispose (object);
 }
 
-static void
-ephy_embed_shell_finalize (GObject *object)
-{
-  EphyEmbedShellPrivate *priv = EPHY_EMBED_SHELL (object)->priv;
-
-  if (priv->downloads != NULL) {
-    LOG ("Destroying downloads list");
-    g_list_foreach (priv->downloads, (GFunc)g_object_unref, NULL);
-    g_list_free (priv->downloads);
-    priv->downloads = NULL;
-  }
-
-  G_OBJECT_CLASS (ephy_embed_shell_parent_class)->finalize (object);
-}
-
-#if HAVE_WEBKIT2
 static void
 web_extension_form_auth_save_requested (GDBusConnection *connection,
                                         const char *sender_name,
@@ -174,7 +141,7 @@ web_extension_proxy_created_cb (GDBusProxy *proxy,
   } else {
     shell->priv->web_extension_form_auth_save_signal_id =
       g_dbus_connection_signal_subscribe (g_dbus_proxy_get_connection (shell->priv->web_extension),
-                                          NULL,
+                                          g_dbus_proxy_get_name (shell->priv->web_extension),
                                           EPHY_WEB_EXTENSION_INTERFACE,
                                          "FormAuthDataSaveConfirmationRequired",
                                           EPHY_WEB_EXTENSION_OBJECT_PATH,
@@ -228,7 +195,6 @@ ephy_embed_shell_watch_web_extension (EphyEmbedShell *shell)
                       shell, NULL);
   g_free (service_name);
 }
-#endif
 
 /**
  * ephy_embed_shell_get_global_history_service:
@@ -306,59 +272,6 @@ ephy_embed_shell_get_frecent_store (EphyEmbedShell *shell)
   return shell->priv->frecent_store;
 }
 
-static GObject *
-impl_get_embed_single (EphyEmbedShell *shell)
-{
-  EphyEmbedShellPrivate *priv;
-
-  g_return_val_if_fail (EPHY_IS_EMBED_SHELL (shell), NULL);
-
-  priv = shell->priv;
-
-  if (priv->embed_single != NULL &&
-      !priv->single_initialised) {
-    g_warning ("ephy_embed_shell_get_embed_single called while the single is being initialised!\n");
-    return G_OBJECT (priv->embed_single);
-  }
-
-  if (priv->embed_single == NULL) {
-    priv->embed_single = EPHY_EMBED_SINGLE (g_object_new (EPHY_TYPE_EMBED_SINGLE, NULL));
-    g_assert (priv->embed_single != NULL);
-
-    if (!ephy_embed_single_initialize (priv->embed_single)) {
-      GtkWidget *dialog;
-
-      dialog = gtk_message_dialog_new (NULL,
-                                       GTK_DIALOG_MODAL,
-                                       GTK_MESSAGE_ERROR,
-                                       GTK_BUTTONS_CLOSE,
-                                       _("Epiphany can't be used now. "
-                                         "Initialization failed."));
-      gtk_dialog_run (GTK_DIALOG (dialog));
-      
-      exit (0);
-    }
-    
-    priv->single_initialised = TRUE;
-  }
-
-  return G_OBJECT (shell->priv->embed_single);
-}
-
-/**
- * ephy_embed_shell_get_embed_single:
- * @shell: the #EphyEmbedShell
- *
- * Return value: (transfer none):
- **/
-GObject *
-ephy_embed_shell_get_embed_single (EphyEmbedShell *shell)
-{
-  EphyEmbedShellClass *klass = EPHY_EMBED_SHELL_GET_CLASS (shell);
-
-  return klass->get_embed_single (shell);
-}
-
 /**
  * ephy_embed_shell_get_encodings:
  * @shell: the #EphyEmbedShell
@@ -388,6 +301,149 @@ ephy_embed_shell_restored_window (EphyEmbedShell *shell)
   g_signal_emit (shell, signals[RESTORED_WINDOW], 0);
 }
 
+static void
+ephy_embed_shell_setup_environment (EphyEmbedShell *shell)
+{
+  EphyEmbedShellMode mode = shell->priv->mode;
+  char *pid_str;
+
+  pid_str = g_strdup_printf ("%u", getpid ());
+  g_setenv ("EPHY_WEB_EXTENSION_ID", pid_str, TRUE);
+  g_setenv ("EPHY_DOT_DIR", ephy_dot_dir (), TRUE);
+  if (EPHY_EMBED_SHELL_MODE_HAS_PRIVATE_PROFILE (mode))
+    g_setenv ("EPHY_PRIVATE_PROFILE", "1", TRUE);
+  g_free (pid_str);
+}
+
+static void
+complete_about_request_for_contents (WebKitURISchemeRequest *request,
+                                     gchar *data,
+                                     gsize data_length)
+{
+  GInputStream *stream;
+
+  stream = g_memory_input_stream_new_from_data (data, data_length, g_free);
+  webkit_uri_scheme_request_finish (request, stream, data_length, "text/html");
+  g_object_unref (stream);
+}
+
+static void
+get_plugins_cb (WebKitWebContext *web_context,
+                GAsyncResult *result,
+                WebKitURISchemeRequest *request)
+{
+  GList *plugins;
+  GString *data_str;
+  gsize data_length;
+
+  data_str = g_string_new("<html>");
+  plugins = webkit_web_context_get_plugins_finish (web_context, result, NULL);
+  _ephy_about_handler_handle_plugins (data_str, plugins);
+  g_string_append (data_str, "</html>");
+
+  data_length = data_str->len;
+  complete_about_request_for_contents (request, g_string_free (data_str, FALSE), data_length);
+  g_object_unref (request);
+}
+
+static void
+about_request_cb (WebKitURISchemeRequest *request,
+                  gpointer user_data)
+{
+  const gchar *path;
+
+  path = webkit_uri_scheme_request_get_path (request);
+  if (!g_strcmp0 (path, "plugins")) {
+    /* Plugins API is async in WebKit2 */
+    webkit_web_context_get_plugins (webkit_web_context_get_default (),
+                                    NULL,
+                                    (GAsyncReadyCallback)get_plugins_cb,
+                                    g_object_ref (request));
+  } else {
+    GString *contents;
+    gsize data_length;
+
+    contents = ephy_about_handler_handle (path);
+    data_length = contents->len;
+    complete_about_request_for_contents (request, g_string_free (contents, FALSE), data_length);
+  }
+}
+
+static void
+ephy_embed_shell_startup (GApplication* application)
+{
+  EphyEmbedShell *shell = EPHY_EMBED_SHELL (application);
+  EphyEmbedShellMode mode;
+  char *disk_cache_dir;
+  WebKitWebContext *web_context;
+  WebKitCookieManager *cookie_manager;
+  char *filename;
+  char *cookie_policy;
+
+  G_APPLICATION_CLASS (ephy_embed_shell_parent_class)->startup (application);
+
+  /* We're not remoting, setup the Web Context. */
+  mode = shell->priv->mode;
+  web_context = webkit_web_context_get_default ();
+
+  ephy_embed_shell_setup_environment (shell);
+
+  /* Set the web extensions dir ASAP before the process is launched. */
+  webkit_web_context_set_web_extensions_directory (web_context, EPHY_WEB_EXTENSIONS_DIR);
+  ephy_embed_shell_watch_web_extension (shell);
+
+  /* Disk Cache */
+  disk_cache_dir = g_build_filename (EPHY_EMBED_SHELL_MODE_HAS_PRIVATE_PROFILE (mode) ?
+                                     ephy_dot_dir () : g_get_user_cache_dir (),
+                                     g_get_prgname (), NULL);
+  webkit_web_context_set_disk_cache_directory (web_context, disk_cache_dir);
+  g_free (disk_cache_dir);
+
+  /* about: URIs handler */
+  webkit_web_context_register_uri_scheme (web_context,
+                                          EPHY_ABOUT_SCHEME,
+                                          (WebKitURISchemeRequestCallback)about_request_cb,
+                                          shell, NULL);
+
+  /* Store cookies in moz-compatible SQLite format */
+  cookie_manager = webkit_web_context_get_cookie_manager (web_context);
+  filename = g_build_filename (ephy_dot_dir (), "cookies.sqlite", NULL);
+  webkit_cookie_manager_set_persistent_storage (cookie_manager, filename,
+                                                WEBKIT_COOKIE_PERSISTENT_STORAGE_SQLITE);
+  g_free (filename);
+
+  cookie_policy = g_settings_get_string (EPHY_SETTINGS_WEB,
+                                         EPHY_PREFS_WEB_COOKIES_POLICY);
+  ephy_embed_prefs_set_cookie_accept_policy (cookie_manager, cookie_policy);
+  g_free (cookie_policy);
+
+
+  ephy_embed_prefs_init ();
+}
+
+static void
+ephy_embed_shell_shutdown (GApplication* application)
+{
+  EphyEmbedShellPrivate *priv = EPHY_EMBED_SHELL (application)->priv;
+
+  G_APPLICATION_CLASS (ephy_embed_shell_parent_class)->shutdown (application);
+
+  if (priv->web_extension_watch_name_id > 0) {
+    g_bus_unwatch_name (priv->web_extension_watch_name_id);
+    priv->web_extension_watch_name_id = 0;
+  }
+
+  if (priv->web_extension_form_auth_save_signal_id > 0) {
+    g_dbus_connection_signal_unsubscribe (g_dbus_proxy_get_connection (priv->web_extension),
+                                          priv->web_extension_form_auth_save_signal_id);
+    priv->web_extension_form_auth_save_signal_id = 0;
+  }
+
+  g_clear_object (&priv->web_extension);
+
+  ephy_embed_prefs_shutdown ();
+}
+
 static void
 ephy_embed_shell_set_property (GObject *object,
                                guint prop_id,
@@ -433,22 +489,23 @@ ephy_embed_shell_init (EphyEmbedShell *shell)
 
   shell->priv->downloads = NULL;
 
-#if HAVE_WEBKIT2
-  ephy_embed_shell_watch_web_extension (shell);
-#endif
+  /* Initialise nspluginwrapper's plugins if available. */
+  if (g_file_test (NSPLUGINWRAPPER_SETUP, G_FILE_TEST_EXISTS) != FALSE)
+    g_spawn_command_line_sync (NSPLUGINWRAPPER_SETUP, NULL, NULL, NULL, NULL);
 }
 
 static void
 ephy_embed_shell_class_init (EphyEmbedShellClass *klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
+  GApplicationClass *application_class = G_APPLICATION_CLASS (klass);
 
   object_class->dispose = ephy_embed_shell_dispose;
-  object_class->finalize = ephy_embed_shell_finalize;
   object_class->set_property = ephy_embed_shell_set_property;
   object_class->get_property = ephy_embed_shell_get_property;
 
-  klass->get_embed_single = impl_get_embed_single;
+  application_class->startup = ephy_embed_shell_startup;
+  application_class->shutdown = ephy_embed_shell_shutdown;
 
   object_properties[PROP_MODE] =
     g_param_spec_enum ("mode",
@@ -589,38 +646,6 @@ ephy_embed_shell_get_default (void)
   return embed_shell;
 }
 
-/**
- * ephy_embed_shell_get_adblock_manager:
- * @shell: the #EphyEmbedShell
- *
- * Returns the adblock manager.
- *
- * Return value: (transfer none): the adblock manager
- **/
-GObject *
-ephy_embed_shell_get_adblock_manager (EphyEmbedShell *shell)
-{
-#ifndef HAVE_WEBKIT2
-  EphyEmbedShellPrivate *priv;
-
-  g_return_val_if_fail (EPHY_IS_EMBED_SHELL (shell), NULL);
-
-  priv = shell->priv;
-
-  if (priv->adblock_manager == NULL) {
-    priv->adblock_manager = g_object_new (EPHY_TYPE_ADBLOCK_MANAGER, NULL);
-
-    ephy_adblock_manager_set_blocker (priv->adblock_manager,
-                                      g_object_new (EPHY_TYPE_ADBLOCK, NULL));
-  }
-
-  return G_OBJECT (priv->adblock_manager);
-#else
-  g_assert_not_reached ();
-  return NULL;
-#endif
-}
-
 void
 ephy_embed_shell_set_page_setup (EphyEmbedShell *shell,
                                  GtkPageSetup *page_setup)
@@ -847,7 +872,6 @@ ephy_embed_shell_launch_handler (EphyEmbedShell *shell,
   return ret;
 }
 
-#ifdef HAVE_WEBKIT2
 GDBusProxy *
 ephy_embed_shell_get_web_extension_proxy (EphyEmbedShell *shell)
 {
@@ -855,4 +879,15 @@ ephy_embed_shell_get_web_extension_proxy (EphyEmbedShell *shell)
 
   return shell->priv->web_extension;
 }
-#endif
+
+/**
+ * ephy_embed_shell_clear_cache:
+ * @shell: an #EphyEmbedShell
+ * 
+ * Clears the HTTP cache (temporarily saved web pages).
+ **/
+void
+ephy_embed_shell_clear_cache (EphyEmbedShell *shell)
+{
+  webkit_web_context_clear_cache (webkit_web_context_get_default ());
+}
