@@ -23,7 +23,6 @@
 #include "config.h"
 
 #include "ephy-debug.h"
-#include "ephy-embed-prefs.h"
 #include "ephy-file-helpers.h"
 #include "ephy-initial-state.h"
 #include "ephy-private.h"
@@ -35,13 +34,16 @@
 #include "ephy-web-app-utils.h"
 
 #include <errno.h>
-#include <gdk/gdkx.h>
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 #include <libnotify/notify.h>
 #include <libxml/xmlversion.h>
 #include <string.h>
 
+#ifdef GDK_WINDOWING_X11
+#include <gdk/gdkx.h>
+#endif
+
 static gboolean open_in_new_tab = FALSE;
 static gboolean open_in_new_window = FALSE;
 
@@ -129,6 +131,11 @@ get_startup_id (void)
   return retval;
 }
 
+#ifdef GDK_WINDOWING_X11
+/*
+ * FIXME: Need a solution for windowing-systems other than X11.
+ */
+
 /* Copied from libnautilus/nautilus-program-choosing.c; Needed in case
  * we have no DESKTOP_STARTUP_ID (with its accompanying timestamp).
  */
@@ -179,6 +186,7 @@ slowly_and_stupidly_obtain_timestamp (Display *xdisplay)
   
   return event.xproperty.time;
 }
+#endif
 
 static void
 show_error_message (GError **error)
@@ -229,9 +237,6 @@ main (int argc,
   EphyShell *ephy_shell;
   int status;
   EphyFileHelpersFlags flags;
-#ifdef HAVE_WEBKIT2
-  char *pid_str;
-#endif
 
 #ifdef ENABLE_NLS
   /* Initialize the i18n stuff */
@@ -338,11 +343,6 @@ main (int argc,
     exit (1);
   }
 
-  if (profile_directory != NULL && private_instance == FALSE && application_mode == FALSE && incognito_mode == FALSE) {
-    g_print ("--profile can only be used in combination with --private-instance, --incognito-mode or --application-mode\n");
-    exit (1);
-  }
-
   if (application_mode && profile_directory == NULL) {
     g_print ("--profile must be used when --application-mode is requested\n");
     exit (1);
@@ -407,9 +407,16 @@ main (int argc,
     arguments = args;
   }
 
+#ifdef GDK_WINDOWING_X11
   /* Get a timestamp manually if need be */
-  if (user_time == 0)
-      user_time = slowly_and_stupidly_obtain_timestamp (GDK_DISPLAY_XDISPLAY (gdk_display_get_default ()));
+  if (user_time == 0) {
+    GdkDisplay* display =
+      gdk_display_manager_get_default_display (gdk_display_manager_get ());
+    if (GDK_IS_X11_DISPLAY (display))
+      user_time =
+        slowly_and_stupidly_obtain_timestamp (GDK_DISPLAY_XDISPLAY (display));
+  }
+#endif
 
   /* Delete the requested web application, if any. Must happen after
    * ephy_file_helpers_init (). */
@@ -421,7 +428,13 @@ main (int argc,
   /* Now create the shell */
   if (private_instance)
     mode = EPHY_EMBED_SHELL_MODE_PRIVATE;
-  else if (incognito_mode) {
+  else if (profile_directory) {
+    /* This mode exists purely for letting EphyShell know it should
+     * not consider this instance part of the unique application
+     * represented by the BROWSER mode.
+     */
+    mode = EPHY_EMBED_SHELL_MODE_STANDALONE;
+  } else if (incognito_mode) {
     mode = EPHY_EMBED_SHELL_MODE_INCOGNITO;
 
     /* Use the right theming. */
@@ -461,18 +474,6 @@ main (int argc,
     gtk_window_set_default_icon_name ("web-browser");
   }
 
-#ifdef HAVE_WEBKIT2
-  pid_str = g_strdup_printf ("%u", getpid ());
-  g_setenv ("EPHY_WEB_EXTENSION_ID", pid_str, TRUE);
-  g_setenv ("EPHY_DOT_DIR", ephy_dot_dir (), TRUE);
-  g_free (pid_str);
-
-  /* Set the web extensions dir ASAP before the process is launched */
-  webkit_web_context_set_web_extensions_directory (webkit_web_context_get_default (),
-                                                   EPHY_WEB_EXTENSIONS_DIR);
-#endif
-
-  ephy_embed_prefs_init ();
   _ephy_shell_create_instance (mode);
 
   startup_flags = get_startup_flags ();
@@ -494,7 +495,6 @@ main (int argc,
     notify_uninit ();
 
   ephy_initial_state_save ();
-  ephy_embed_prefs_shutdown ();
   ephy_settings_shutdown ();
   ephy_file_helpers_shutdown ();
   xmlCleanupParser ();
