@@ -28,7 +28,6 @@
 #include "ephy-embed-container.h"
 #include "ephy-embed-prefs.h"
 #include "ephy-embed-shell.h"
-#include "ephy-embed-single.h"
 #include "ephy-embed-utils.h"
 #include "ephy-encodings.h"
 #include "ephy-file-chooser.h"
@@ -1087,7 +1086,7 @@ prefs_dialog_init (PrefsDialog *pd)
 			  G_CALLBACK (clear_cache_button_clicked_cb), dialog);
 
 	encodings = EPHY_ENCODINGS (ephy_embed_shell_get_encodings
-					(EPHY_EMBED_SHELL (ephy_shell)));
+					(EPHY_EMBED_SHELL (ephy_shell_get_default ())));
 
 	create_node_combo (dialog, encodings, "ISO-8859-1");
 
