@@ -31,7 +31,6 @@
 #include "ephy-embed-container.h"
 #include "ephy-embed-prefs.h"
 #include "ephy-embed-shell.h"
-#include "ephy-embed-single.h"
 #include "ephy-embed-utils.h"
 #include "ephy-embed.h"
 #include "ephy-favicon-helpers.h"
@@ -625,6 +624,12 @@ download_icon_and_set_image (EphyApplicationDialogData *data)
 #ifdef HAVE_WEBKIT2
 	download = webkit_web_context_download_uri (webkit_web_context_get_default (),
 						    data->icon_href);
+	/* We do not want this download to show up in the UI, so let's
+	 * set 'ephy-download-set' to make Epiphany think this is
+	 * already there. */
+	/* FIXME: it's probably better to just do this in a clean way
+	 * instead of using this workaround. */
+	g_object_set_data (G_OBJECT (download), "ephy-download-set", GINT_TO_POINTER (TRUE));
 #else
 	request = webkit_network_request_new (data->icon_href);
 	download = webkit_download_new (request);
@@ -1051,21 +1056,6 @@ window_cmd_file_save_as_application (GtkAction *action,
 	gtk_widget_show_all (dialog);
 }
 
-void
-window_cmd_file_work_offline (GtkAction *action,
-		              EphyWindow *window)
-{
-        /* TODO: WebKitGTK+ does not currently support offline status. */
-#if 0
-	EphyEmbedSingle *single;
-	gboolean offline;
-
-	single = EPHY_EMBED_SINGLE (ephy_embed_shell_get_embed_single (ephy_embed_shell_get_default ()));
-	offline = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action));
-	ephy_embed_single_set_network_status (single, !offline);
-#endif
-}
-
 void
 window_cmd_file_close_window (GtkAction *action,
 		              EphyWindow *window)
